# CHANGELOG

## 0.1.0

* Add first implementation of Motra M2T including:
  * `@template`, `@main`, `@helper`
  * polymorphic calls
  * cached results
* Introduce more flexible polymorphic calls for M2M.
* Add new examples.

## 0.0.4

* Fix issue with result being automatically moved to resource root.

## 0.0.1

* Initial version with Motra M2M including:
  * `@mapping`, `@main`, `@disjunct`
  * polymorphic calls
  * cached results
